@@ -68,20 +68,23 @@ settings_t *settings_load(void) {
 
   /* ------ set useful defaults ------- */
 
-  char *p = getenv("HOME");
-  g_assert(p);
+  char *p = NULL;
+#ifdef USE_HILDON
+  /* try to use internal memory card on hildon/maemo */
+  p = getenv("INTERNAL_MMC_MOUNTPOINT");
+  if(!p) 
+#endif
+    p = getenv("HOME");
+  
+  /* if everthing fails use tmp dir */
+  if(!p) p = "/tmp";
+  
+  /* build image path in home directory */
+  if(strncmp(p, "/home", 5) == 0) 
+    settings->base_path = g_strdup_printf("%s/.osm2go/", p);
+  else
+    settings->base_path = g_strdup_printf("%s/osm2go/", p);
 
-  if (*BASE_DIR == '/')  /* absolute path */
-    settings->base_path = strdup(BASE_DIR);
-  else {
-    /* build image path in home directory */
-    settings->base_path =
-      malloc(strlen(p)+strlen(BASE_DIR)+2);
-    strcpy(settings->base_path, p);
-    if(settings->base_path[strlen(settings->base_path)-1] != '/')
-      strcat(settings->base_path, "/");
-    strcat(settings->base_path, BASE_DIR);
-  }
   fprintf(stderr, "base_path = %s\n", settings->base_path);
 
   /* ------------- setup download defaults -------------------- */
@@ -119,9 +122,8 @@ settings_t *settings_load(void) {
 		   "problems displaying icons on the map, icons have been "
 		   "disabled. You might enable them in the menu under "
 		   "Map/No Icons at any time."));
-
-	settings->no_icons = TRUE;
 #endif
+	settings->no_icons = TRUE;
       }
     }
 #endif
